Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Bap_strings_unscrambler.Make
Make(Alphabet) creates an unscrambler for the given alphabet.
The unscrambler will build all words from the provided sequence of characters, essentially it is the same as playing scrabble. For example, from characters h,e,l,l,o it will build words "hell", "hello", "ell", "hoe", and so on, provided that they are known to the unscrambler, i.e., present in its dictionary.
The unscrambler requires to know the alphabet of the language beforehand, because it uses efficient trie-like representation of the dictionary that enables O(1) search for words (O(1) in terms of the dictionary size).